;; Generated package description from auth-source-xoauth2-plugin.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "auth-source-xoauth2-plugin" "0.4" "Authentication source plugin for xoauth2" '((emacs "28.1") (oauth2 "0.18")) :commit "913134419ed0a8d66f33407908919730c89def69" :authors '(("Xiyue Deng" . "manphiz@gmail.com")) :maintainer '("Xiyue Deng" . "manphiz@gmail.com") :url "https://gitlab.com/manphiz/auth-source-xoauth2-plugin")
